@@ -1,12 +1,12 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
+/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
+ * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2001 Bastien Nocera <hadess@hadess.net>
- * Copyright (C) 2017 Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020 KylinSoft Co., Ltd.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,15 +14,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #ifndef __ACME_H__
 #define __ACME_H__
 
-#include "usd-keygrab.h"
+#include "ukui-keygrab.h"
 
 #define BINDING_SCHEMA "org.ukui.SettingsDaemon.plugins.media-keys"
 
@@ -39,6 +36,7 @@ enum {
         SEARCH_KEY,
         EMAIL_KEY,
         SCREENSAVER_KEY,
+        SCREENSAVER_KEY_2,
         HELP_KEY,
         WWW_KEY,
         PLAY_KEY,
@@ -52,14 +50,22 @@ enum {
         RANDOM_KEY,
         MAGNIFIER_KEY,
         SCREENREADER_KEY,
+        //SIDEBAR_KEY,
+        SIDEBAR_KEY_2,
         SETTINGS_KEY,
+        WINDOWSWITCH_KEY,
+        WINDOWSWITCH_KEY_2,
         FILE_MANAGER_KEY,
+        FILE_MANAGER_KEY_2,
         ON_SCREEN_KEYBOARD_KEY,
         LOGOUT_KEY,
         TERMINAL_KEY,
+        TERMINAL_KEY_2,
         SCREENSHOT_KEY,
         WINDOW_SCREENSHOT_KEY,
         AREA_SCREENSHOT_KEY,
+        SYSTEM_MONITOR_KEY,
+        CONNECTION_EDITOR_KEY,
         HANDLED_KEYS,
 };
 
@@ -81,8 +87,14 @@ static struct {
         { SEARCH_KEY, "search", NULL, NULL },
         { EMAIL_KEY, "email", NULL, NULL },
         { SCREENSAVER_KEY, "screensaver", NULL, NULL },
+        { SCREENSAVER_KEY_2, "screensaver2", NULL, NULL },
+        //{ SIDEBAR_KEY, "ukui-sidebar", NULL, NULL },
+        { SIDEBAR_KEY_2, "ukui-sidebar2", NULL, NULL },
         { SETTINGS_KEY, "ukui-control-center", NULL, NULL},
+        { WINDOWSWITCH_KEY, "ukui-window-switch", NULL, NULL},
+        { WINDOWSWITCH_KEY_2, "ukui-window-switch2", NULL, NULL},
         { FILE_MANAGER_KEY, "peony-qt", NULL, NULL},
+        { FILE_MANAGER_KEY_2, "peony-qt2", NULL, NULL},
         { HELP_KEY, "help", NULL, NULL },
         { WWW_KEY, "www", NULL, NULL },
         { PLAY_KEY, "play", NULL, NULL },
@@ -100,9 +112,12 @@ static struct {
         { ON_SCREEN_KEYBOARD_KEY, "on-screen-keyboard", NULL, NULL },
         { LOGOUT_KEY, "logout", NULL, NULL },
         { TERMINAL_KEY, "terminal", NULL, NULL },
+        { TERMINAL_KEY_2, "terminal2", NULL, NULL },
         { SCREENSHOT_KEY, "screenshot", NULL, NULL },
         { WINDOW_SCREENSHOT_KEY, "window-screenshot", NULL, NULL },
         { AREA_SCREENSHOT_KEY, "area-screenshot", NULL, NULL },
+        { SYSTEM_MONITOR_KEY, "ukui-system-monitor", NULL, NULL },
+        { CONNECTION_EDITOR_KEY, "nm-connection-editor", NULL, NULL },
 };
 
 #endif /* __ACME_H__ */
